@@ -9,7 +9,7 @@ def google_photos(src, width, height, alt="photo", place="photo", scale=nil)
 	scale = scale || @conf['google_photos.scale'] || 100
 	width = width.to_i * (scale.to_f / 100)
 	height = height.to_i * (scale.to_f / 100)
-	%Q|<img title="#{alt}" width="#{width}" height="#{height}" alt="#{alt}" src="#{src}" class="#{place} google">|
+	%Q|<img title="#{alt}" width="#{width.to_i}" height="#{height.to_i}" alt="#{alt}" src="#{src}" class="#{place} google">|
 end
 
 def google_photos_left(src, width, height, alt="photo", scale=nil)
