@@ -9,7 +9,7 @@ describe "github link plugin" do
 		let(:args) { ['tdiary/tdiary-contrib'] }
 
 		it 'should render repository a tag' do
-			should == %(<a href='https://github.com/tdiary/tdiary-contrib'>tdiary-contrib</a>)
+			is_expected.to eq(%(<a href='https://github.com/tdiary/tdiary-contrib'>tdiary-contrib</a>))
 		end
 	end
 
@@ -17,7 +17,7 @@ describe "github link plugin" do
 		let(:args) { ['tdiary/tdiary-contrib#100'] }
 
 		it 'should render issues a tag' do
-			should == %(<a href='https://github.com/tdiary/tdiary-contrib/issues/100'>tdiary-contrib#100</a>)
+			is_expected.to eq(%(<a href='https://github.com/tdiary/tdiary-contrib/issues/100'>tdiary-contrib#100</a>))
 		end
 	end
   context "When given altenative text" do
@@ -26,13 +26,13 @@ describe "github link plugin" do
     let(:args) { [github_identifier, text] }
 
 		it 'should render repository a tag with the specified text' do
-			should == %(<a href='https://github.com/#{github_identifier}'>#{text}</a>)
+			is_expected.to eq(%(<a href='https://github.com/#{github_identifier}'>#{text}</a>))
 		end
     context "but the text is including <script>" do
       let(:text) { '<script>alert("hoge");</script>' }
 
       it 'should render a link text after sanitizing.' do
-        should_not == %(<a href='https://github.com/#{github_identifier}'>#{text}</a>)
+        is_expected.not_to eq(%(<a href='https://github.com/#{github_identifier}'>#{text}</a>))
       end
     end
   end
